@@ -102,7 +102,6 @@ static char *brackchr[] = {
  * ptonum is, if not NULL, a pointer to the part number in the subject line,
  * so that it won't be used as filename.
  **/
-
 static char *
 UUGetFileName (char *subject, char *ptonum, char *ptonend)
 {
@@ -1191,6 +1190,11 @@ UUInsertPartToList (uufile *data)
     return UURET_NOMEM;
   }
 
+  {
+    static uulist uulist_new;
+    *unew = uulist_new; /* zero-initialise the structure */
+  }
+
   if ((unew->subfname = _FP_strdup (data->subfname)) == NULL) {
     _FP_free (unew);
     return UURET_NOMEM;
@@ -1230,16 +1234,12 @@ UUInsertPartToList (uufile *data)
     unew->mimetype = NULL;
 
   unew->state     = UUFILE_READ;
-  unew->binfile   = NULL;
   unew->thisfile  = data;
   unew->mode      = data->data->mode;
   unew->uudet     = data->data->uudet;
   unew->flags     = data->data->flags;
-  unew->begin     = (data->data->begin) ? ((data->partno)?data->partno:1) : 0;
-  unew->end       = (data->data->end)   ? ((data->partno)?data->partno:1) : 0;
-  unew->misparts  = NULL;
-  unew->haveparts = NULL;
-  unew->NEXT      = NULL;
+  unew->begin     = data->data->begin ? (data->partno ? data->partno : 1) : 0;
+  unew->end       = data->data->end   ? (data->partno ? data->partno : 1) : 0;
 
   if (iter == NULL)
     UUGlobalFileList = unew;
